@@ -144,6 +144,12 @@ static inline Quantum GetPixelCompositeMask(
   return(pixel[image->channel_map[CompositeMaskPixelChannel].offset]);
 }
 
+static inline PixelTrait GetPixelCompositeMaskTraits(
+  const Image *magick_restrict image)
+{
+  return(image->channel_map[CompositeMaskPixelChannel].traits);
+}
+
 static inline Quantum GetPixelCr(const Image *magick_restrict image,
   const Quantum *magick_restrict pixel)
 {
@@ -357,6 +363,16 @@ static inline Quantum GetPixelReadMask(const Image *magick_restrict image,
   return(pixel[image->channel_map[ReadMaskPixelChannel].offset]);
 }
 
+static inline void GetPixelInfoRGBA(const Quantum red,const Quantum green,
+  const Quantum blue,const Quantum alpha,PixelInfo *magick_restrict pixel)
+{
+  GetPixelInfo((Image *) NULL,pixel);
+  pixel->red=red;
+  pixel->green=green;
+  pixel->blue=blue;
+  pixel->alpha=alpha;
+}
+
 static inline Quantum GetPixelWriteMask(
   const Image *magick_restrict image,const Quantum *magick_restrict pixel)
 {
@@ -444,6 +460,12 @@ static inline PixelTrait GetPixelTraits(const Image *magick_restrict image,
   return(image->channel_map[channel].traits);
 }
 
+static inline PixelTrait GetPixelWriteMaskTraits(
+  const Image *magick_restrict image)
+{
+  return(image->channel_map[WriteMaskPixelChannel].traits);
+}
+
 static inline Quantum GetPixelY(const Image *magick_restrict image,
   const Quantum *magick_restrict pixel)
 {
@@ -651,7 +673,7 @@ static inline void SetPixelb(const Image *magick_restrict image,
     pixel[image->channel_map[bPixelChannel].offset]=b;
 }
 
-static inline void SetPixelBackgoundColor(const Image *magick_restrict image,
+static inline void SetPixelBackgroundColor(const Image *magick_restrict image,
   Quantum *magick_restrict pixel)
 {
   ssize_t
@@ -674,6 +696,15 @@ static inline void SetPixelBackgoundColor(const Image *magick_restrict image,
       ClampToQuantum(image->background_color.alpha);
 }
 
+static inline void SetPixelBackgoundColor(const Image *magick_restrict image,
+  Quantum *magick_restrict pixel) magick_attribute((deprecated));
+
+static inline void SetPixelBackgoundColor(const Image *magick_restrict image,
+  Quantum *magick_restrict pixel)
+{
+  SetPixelBackgroundColor(image,pixel);
+}
+
 static inline void SetPixelBlack(const Image *magick_restrict image,
   const Quantum black,Quantum *magick_restrict pixel)
 {
@@ -859,13 +890,6 @@ static inline void SetPixelReadMask(const Image *magick_restrict image,
     pixel[image->channel_map[ReadMaskPixelChannel].offset]=mask;
 }
 
-static inline void SetPixelWriteMask(const Image *magick_restrict image,
-  const Quantum mask,Quantum *magick_restrict pixel)
-{
-  if (image->channel_map[WriteMaskPixelChannel].traits != UndefinedPixelTrait)
-    pixel[image->channel_map[WriteMaskPixelChannel].offset]=mask;
-}
-
 static inline void SetPixelMetacontentExtent(Image *image,const size_t extent)
 {
   image->metacontent_extent=extent;
@@ -889,6 +913,13 @@ static inline void SetPixelRedTraits(Image *image,const PixelTrait traits)
   image->channel_map[RedPixelChannel].traits=traits;
 }
 
+static inline void SetPixelWriteMask(const Image *magick_restrict image,
+  const Quantum mask,Quantum *magick_restrict pixel)
+{
+  if (image->channel_map[WriteMaskPixelChannel].traits != UndefinedPixelTrait)
+    pixel[image->channel_map[WriteMaskPixelChannel].offset]=mask;
+}
+
 static inline void SetPixelYellow(const Image *magick_restrict image,
   const Quantum yellow,Quantum *magick_restrict pixel)
 {
